const convert12hTo24h = (abbr, hour) => {
    if (abbr === 'am' && hour === 12) {
        return 0;
    }
    if (abbr === 'am') {
        return hour;
    }
    if (abbr === 'pm' && hour === 12) {
        return 12;
    }
    return hour + 12;
};
const convert24hTo12h = (hour) => hour % 12 || 12;
const convertTimeToDate = (time) => time ? (time instanceof Date ? new Date(time) : new Date(`1970-01-01 ${time}`)) : null;
const getAmPm = (date, locale) => {
    if (date.toLocaleTimeString(locale).includes('AM')) {
        return 'am';
    }
    if (date.toLocaleTimeString(locale).includes('PM')) {
        return 'pm';
    }
    return date.getHours() >= 12 ? 'pm' : 'am';
};
const getLocalizedTimePartials = (locale, ampm = 'auto') => {
    const date = new Date();
    const hour12 = ['am', 'AM', 'pm', 'PM'].some((el) => date.toLocaleString(locale).includes(el));
    const listOfHours = Array.from({ length: (ampm === 'auto' && hour12) || ampm === true ? 12 : 24 }, (_, i) => {
        return {
            value: (ampm === 'auto' && hour12) || ampm === true ? i + 1 : i,
            label: ((ampm === 'auto' && hour12) || ampm === true ? i + 1 : i).toLocaleString(locale),
        };
    });
    const listOfMinutesSeconds = Array.from({ length: 60 }, (_, i) => {
        date.setMinutes(i);
        return {
            value: i,
            label: date
                .toLocaleTimeString(locale, {
                minute: '2-digit',
                second: '2-digit',
            })
                .split(/[^A-Za-z0-9\u06F0-\u06F90-9]/)[0],
        };
    });
    return {
        listOfHours,
        listOfMinutes: listOfMinutesSeconds,
        listOfSeconds: listOfMinutesSeconds,
        hour12,
    };
};
const getSelectedHour = (date, locale, ampm = 'auto') => date
    ? (ampm === 'auto' && isAmPm(locale)) || ampm === true
        ? convert24hTo12h(date.getHours())
        : date.getHours()
    : '';
const getSelectedMinutes = (date) => (date ? date.getMinutes() : '');
const getSelectedSeconds = (date) => (date ? date.getSeconds() : '');
const isAmPm = (locale) => ['am', 'AM', 'pm', 'PM'].some((el) => new Date().toLocaleString(locale).includes(el));
const isValidTime = (time) => {
    const d = new Date(`1970-01-01 ${time}`);
    return d instanceof Date && d.getTime();
};

export { convert12hTo24h, convert24hTo12h, convertTimeToDate, getAmPm, getLocalizedTimePartials, getSelectedHour, getSelectedMinutes, getSelectedSeconds, isAmPm, isValidTime };
//# sourceMappingURL=utils.js.map
